[cfe-commits] r45290 - /cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h

Ted Kremenek kremenek at apple.com
Fri Dec 21 13:16:58 PST 2007


Author: kremenek
Date: Fri Dec 21 15:16:58 2007
New Revision: 45290

URL: http://llvm.org/viewvc/llvm-project?rev=45290&view=rev
Log:
Renamed class AnalysisVertex to SimulVertex

Modified:
    cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h

Modified: cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h?rev=45290&r1=45289&r2=45290&view=diff

==============================================================================
--- cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h (original)
+++ cfe/trunk/include/clang/Analysis/PathSensitive/AnalysisVertex.h Fri Dec 21 15:16:58 2007
@@ -1,4 +1,4 @@
 //=- AnalysisVertex.h - Local, Path-Sensitive Supergraph Vertices -*- C++ -*-=//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 //  This file defines the template class AnalysisVertex which is used to
 //  represent a vertex in the location*state supergraph of an intra-procedural,
 //  path-sensitive dataflow analysis.
 //
@@ -24,7 +24,7 @@
 class ProgramEdge;
   
 template <typename StateTy>
-class AnalysisVertex {
+class SimulVertex {
   /// VertexID - A unique ID for the vertex.  This number indicates the
   ///  creation order of vertices, with lower numbers being created first.
   ///  The first created vertex has VertexID == 0.
@@ -41,12 +41,12 @@
 
   /// Predecessors/Successors - Keep track of the predecessor/successor
   /// vertices.
-  typedef llvm::SmallVector<1> AdjacentVertices;
+  typedef llvm::SmallVector<1,SimulVertex*> AdjacentVertices;
   AdjacentVertices Preds;
   AdjacentVertices Succs;
 
 public:
-  explicit AnalysisVertex(unsigned ID, const ProgramEdge& loc, StateTy* state)
+  explicit SimulVertex(unsigned ID, const ProgramEdge& loc, StateTy* state)
     : VertexID(ID), Location(loc), State(state) {}
   
   // Accessors.
@@ -79,8 +79,8 @@
   unsigned pred_empty() const { return Preds.empty(); }
   
   // Manipulation of successors/predecessors.
-  void addPredecessor(AnalysisVertex* V) {
-    Preds.push_back(&V);
+  void addPredecessor(SimulVertex* V) {
+    Preds.push_back(V);
     V.Succs.push_back(V);
   }  
 };
@@ -1,4 +1,4 @@
-//=- AnalysisVertex.h - Local, Path-Sensitive Supergraph Vertices -*- C++ -*-=//
+//=- SimulVertex.h - Local, Path-Sensitive Supergraph Vertices -*- C++ -*--=//
 //
 //                     The LLVM Compiler Infrastructure
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-//  This file defines the template class AnalysisVertex which is used to
+//  This file defines the template class SimulVertex which is used to
 //  represent a vertex in the location*state supergraph of an intra-procedural,
 //  path-sensitive dataflow analysis.





More information about the cfe-commits mailing list